@@ -39,6 +39,7 @@
 #include <osl/mutex.hxx>
 #include <vcl/window.hxx>
 #include <vcl/settings.hxx>
+#include <vcl/svapp.hxx>
 
 //......................................................................................................................
 namespace toolkit
@@ -69,13 +70,11 @@ namespace toolkit
     //==================================================================================================================
     struct WindowStyleSettings_Data
     {
-        ::osl::SolarMutex&                      rMutex;
         VCLXWindow*                         pOwningWindow;
         ::cppu::OInterfaceContainerHelper   aStyleChangeListeners;
 
-        WindowStyleSettings_Data( ::osl::SolarMutex& i_rWindowMutex, ::osl::Mutex& i_rListenerMutex, VCLXWindow& i_rOwningWindow )
-            :rMutex( i_rWindowMutex )
-            ,pOwningWindow( &i_rOwningWindow )
+        WindowStyleSettings_Data( ::osl::Mutex& i_rListenerMutex, VCLXWindow& i_rOwningWindow )
+            : pOwningWindow( &i_rOwningWindow )
             ,aStyleChangeListeners( i_rListenerMutex )
         {
         }
@@ -106,7 +105,6 @@ namespace toolkit
     {
     public:
         StyleMethodGuard( WindowStyleSettings_Data& i_rData )
-            :m_aGuard( i_rData.rMutex )
         {
             if ( i_rData.pOwningWindow == NULL )
                 throw DisposedException();
@@ -117,15 +115,15 @@ namespace toolkit
         }
 
     private:
-        ::osl::SolarGuard   m_aGuard;
+        SolarMutexGuard  m_aGuard;
     };
 
     //==================================================================================================================
     //= WindowStyleSettings
     //==================================================================================================================
     //------------------------------------------------------------------------------------------------------------------
-    WindowStyleSettings::WindowStyleSettings( ::osl::SolarMutex& i_rWindowMutex, ::osl::Mutex& i_rListenerMutex, VCLXWindow& i_rOwningWindow )
-        :m_pData( new WindowStyleSettings_Data( i_rWindowMutex, i_rListenerMutex, i_rOwningWindow ) )
+    WindowStyleSettings::WindowStyleSettings(::osl::Mutex& i_rListenerMutex, VCLXWindow& i_rOwningWindow )
+        :m_pData( new WindowStyleSettings_Data(i_rListenerMutex, i_rOwningWindow ) )
     {
         Window* pWindow = i_rOwningWindow.GetWindow();
         if ( !pWindow )
