@@ -30,6 +30,7 @@
 #include "svpbmp.hxx"
 
 #include <vcl/sysdata.hxx>
+#include <vcl/region.h>
 #include <basegfx/range/b2drange.hxx>
 #include <basegfx/range/b2irange.hxx>
 #include <basegfx/polygon/b2dpolypolygon.hxx>
@@ -63,7 +64,7 @@ rDevice
     aBuf.append( "debug" );
     mkdir( aBuf.getStr(), 0777 );
     aBuf.append( "/" );
-    aBuf.append( sal_Int64(reinterpret_cast<sal_uInt32>(rDevice.get())), 16 );
+    aBuf.append( sal_Int64(reinterpret_cast<sal_IntPtr>(rDevice.get())), 16 );
     mkdir( aBuf.getStr(), 0777 );
     aBuf.append( "/bmp" );
     aBuf.append( sal_Int32(dbgStreamNum++) );
@@ -132,7 +133,7 @@ void SvpSalGraphics::GetResolution( sal_Int32& rDPIX, sal_Int32& rDPIY )
     rDPIX = rDPIY = 96;
 }
 
-USHORT SvpSalGraphics::GetBitCount()
+sal_uInt16 SvpSalGraphics::GetBitCount() const
 {
     return SvpElement::getBitCountFromScanlineFormat( m_aDevice->getScanlineFormat() );
 }
@@ -153,11 +154,16 @@ void SvpSalGraphics::ResetClipRegion()
     m_aClipMap.reset();
 }
 
-void SvpSalGraphics::BeginSetClipRegion( ULONG n )
+bool SvpSalGraphics::setClipRegion( const Region& i_rClip )
 {
-    if( n <= 1 )
+    if( i_rClip.IsEmpty() )
+        m_aClipMap.reset();
+    else if( i_rClip.GetRectCount() == 1 )
     {
         m_aClipMap.reset();
+        Rectangle aBoundRect( i_rClip.GetBoundRect() );
+        m_aDevice = basebmp::subsetBitmapDevice( m_aOrigDevice,
+                                                 basegfx::B2IRange(aBoundRect.Left(),aBoundRect.Top(),aBoundRect.Right(),aBoundRect.Bottom()) );
     }
     else
     {
@@ -165,34 +171,22 @@ void SvpSalGraphics::BeginSetClipRegion( ULONG n )
         B2IVector aSize = m_aDevice->getSize();
         m_aClipMap = createBitmapDevice( aSize, false, Format::ONE_BIT_MSB_GREY );
         m_aClipMap->clear( basebmp::Color(0xFFFFFFFF) );
+
+        ImplRegionInfo aInfo;
+        long nX, nY, nW, nH;
+        bool bRegionRect = i_rClip.ImplGetFirstRect(aInfo, nX, nY, nW, nH );
+        while( bRegionRect )
+        {
+            if ( nW && nH )
+            {
+                B2DPolyPolygon aFull;
+                aFull.append( tools::createPolygonFromRect( B2DRectangle( nX, nY, nX+nW, nY+nH ) ) ); 
+                m_aClipMap->fillPolyPolygon( aFull, basebmp::Color(0), DrawMode_PAINT );
+            }
+            bRegionRect = i_rClip.ImplGetNextRect( aInfo, nX, nY, nW, nH );
+        }
     }
-}
-
-BOOL SvpSalGraphics::unionClipRegion( long nX, long nY, long nWidth, long nHeight )
-{
-    if( m_aClipMap )
-    {
-        B2DPolyPolygon aFull;
-        aFull.append( tools::createPolygonFromRect( B2DRectangle( nX, nY, nX+nWidth, nY+nHeight ) ) ); 
-        m_aClipMap->fillPolyPolygon( aFull, basebmp::Color(0), DrawMode_PAINT );
-    }
-    else
-    {
-        m_aDevice = basebmp::subsetBitmapDevice( m_aOrigDevice,
-                                                 basegfx::B2IRange(nX,nY,nX+nWidth,nY+nHeight) );
-    }
-
-    return TRUE;
-}
-
-bool SvpSalGraphics::unionClipRegion( const ::basegfx::B2DPolyPolygon& )
-{
-        // TODO: implement and advertise OutDevSupport_B2DClip support
-        return false;
-}
-
-void SvpSalGraphics::EndSetClipRegion()
-{
+    return true;
 }
 
 void SvpSalGraphics::SetLineColor()
@@ -310,13 +304,13 @@ void SvpSalGraphics::drawRect( long nX, long nY, long nWidth, long nHeight )
     dbgOut( m_aDevice );
 }
 
-void SvpSalGraphics::drawPolyLine( ULONG nPoints, const SalPoint* pPtAry )
+void SvpSalGraphics::drawPolyLine( sal_uLong nPoints, const SalPoint* pPtAry )
 {
     if( m_bUseLineColor && nPoints )
     {
         B2DPolygon aPoly;
         aPoly.append( B2DPoint( pPtAry->mnX, pPtAry->mnY ), nPoints );
-        for( ULONG i = 1; i < nPoints; i++ )
+        for( sal_uLong i = 1; i < nPoints; i++ )
             aPoly.setB2DPoint( i, B2DPoint( pPtAry[i].mnX, pPtAry[i].mnY ) );
         aPoly.setClosed( false );
         m_aDevice->drawPolygon( aPoly, m_aLineColor, m_aDrawMode, m_aClipMap );
@@ -324,13 +318,13 @@ void SvpSalGraphics::drawPolyLine( ULONG nPoints, const SalPoint* pPtAry )
     dbgOut( m_aDevice );
 }
 
-void SvpSalGraphics::drawPolygon( ULONG nPoints, const SalPoint* pPtAry )
+void SvpSalGraphics::drawPolygon( sal_uLong nPoints, const SalPoint* pPtAry )
 {
     if( ( m_bUseLineColor || m_bUseFillColor ) && nPoints )
     {
         B2DPolygon aPoly;
         aPoly.append( B2DPoint( pPtAry->mnX, pPtAry->mnY ), nPoints );
-        for( ULONG i = 1; i < nPoints; i++ )
+        for( sal_uLong i = 1; i < nPoints; i++ )
             aPoly.setB2DPoint( i, B2DPoint( pPtAry[i].mnX, pPtAry[i].mnY ) );
         if( m_bUseFillColor )
         {
@@ -361,7 +355,7 @@ void SvpSalGraphics::drawPolyPolygon( sal_uInt32        nPoly,
                 PCONSTSALPOINT pPoints = pPtAry[nPolygon];
                 B2DPolygon aPoly;
                 aPoly.append( B2DPoint( pPoints->mnX, pPoints->mnY ), nPoints );
-                for( ULONG i = 1; i < nPoints; i++ )
+                for( sal_uInt32 i = 1; i < nPoints; i++ )
                     aPoly.setB2DPoint( i, B2DPoint( pPoints[i].mnX, pPoints[i].mnY ) );
 
                 aPolyPoly.append( aPoly );
@@ -389,16 +383,16 @@ bool SvpSalGraphics::drawPolyLine( const ::basegfx::B2DPolygon&, double /*fTrans
         return false;
 }
 
-sal_Bool SvpSalGraphics::drawPolyLineBezier( ULONG,
+sal_Bool SvpSalGraphics::drawPolyLineBezier( sal_uLong,
                                              const SalPoint*,
-                                             const BYTE* )
+                                             const sal_uInt8* )
 {
     return sal_False;
 }
 
-sal_Bool SvpSalGraphics::drawPolygonBezier( ULONG,
+sal_Bool SvpSalGraphics::drawPolygonBezier( sal_uLong,
                                             const SalPoint*,
-                                            const BYTE* )
+                                            const sal_uInt8* )
 {
     return sal_False;
 }
@@ -406,7 +400,7 @@ sal_Bool SvpSalGraphics::drawPolygonBezier( ULONG,
 sal_Bool SvpSalGraphics::drawPolyPolygonBezier( sal_uInt32,
                                                 const sal_uInt32*,
                                                 const SalPoint* const*,
-                                                const BYTE* const* )
+                                                const sal_uInt8* const* )
 {
     return sal_False;
 }
@@ -423,7 +417,7 @@ void SvpSalGraphics::copyArea( long nDestX,
                                       long nSrcY,
                                       long nSrcWidth,
                                       long nSrcHeight,
-                                      USHORT /*nFlags*/ )
+                                      sal_uInt16 /*nFlags*/ )
 {
     B2IRange aSrcRect( nSrcX, nSrcY, nSrcX+nSrcWidth, nSrcY+nSrcHeight );
     B2IRange aDestRect( nDestX, nDestY, nDestX+nSrcWidth, nDestY+nSrcHeight );
@@ -539,21 +533,21 @@ void SvpSalGraphics::invert( long nX, long nY, long nWidth, long nHeight, SalInv
     dbgOut( m_aDevice );
 }
 
-void SvpSalGraphics::invert( ULONG nPoints, const SalPoint* pPtAry, SalInvert /*nFlags*/ )
+void SvpSalGraphics::invert( sal_uLong nPoints, const SalPoint* pPtAry, SalInvert /*nFlags*/ )
 {
     // FIXME: handle SAL_INVERT_50 and SAL_INVERT_TRACKFRAME
     B2DPolygon aPoly;
     aPoly.append( B2DPoint( pPtAry->mnX, pPtAry->mnY ), nPoints );
-    for( ULONG i = 1; i < nPoints; i++ )
+    for( sal_uLong i = 1; i < nPoints; i++ )
         aPoly.setB2DPoint( i, B2DPoint( pPtAry[i].mnX, pPtAry[i].mnY ) );
     aPoly.setClosed( true );
     m_aDevice->fillPolyPolygon( B2DPolyPolygon(aPoly), basebmp::Color( 0xffffff ), DrawMode_XOR, m_aClipMap );
     dbgOut( m_aDevice );
 }
 
-BOOL SvpSalGraphics::drawEPS( long, long, long, long, void*, ULONG )
+sal_Bool SvpSalGraphics::drawEPS( long, long, long, long, void*, sal_uLong )
 {
-    return FALSE;
+    return sal_False;
 }
 
 SystemFontData SvpSalGraphics::GetSysFontData( int nFallbacklevel ) const
